#' Sample Data
#'
#' This sample data is a dataset used in: Nicolosi Gelis, María Mercedes; Cochero, Joaquín; Donadelli, Jorge; Gómez, Nora. 2020. "Exploring the use of nuclear alterations, motility and ecological guilds in epipelic diatoms as biomonitoring tools for water quality improvement in urban impacted lowland streams". Ecological Indicators, 110, 105951.
#'
#' @format A data frame with the abundance of 164 diatoms in 108 sampled sites
#' @docType data
#' @usage data(diat_sampleData)
#' @encoding UTF-8
#' @source \doi{10.1016/j.ecolind.2019.105951}
#' @references Nicolosi Gelis, María Mercedes; Cochero, Joaquín; Donadelli, Jorge; Gómez, Nora. 2020. "Exploring the use of nuclear alterations, motility and ecological guilds in epipelic diatoms as biomonitoring tools for water quality improvement in urban impacted lowland streams". Ecological Indicators, 110, 105951.
"diat_sampleData"

#' DBC (offline)
#'
#' Diatom database from the 'Diat.Barcode' project V9.0
#'
#' @format A data frame with ecological and morphological information for 8066 diatoms
#' @docType data
#' @usage data(dbc_offline)
#' @encoding UTF-8
#' @source \url{https://www.kmae-journal.org/articles/kmae/abs/2012/03/kmae120025/kmae120025.html}
#' @references Rimet F. & Bouchez A., 2012. Life-forms, cell-sizes and ecological guilds of diatoms in European rivers. Knowledge and management of aquatic ecosystems, 406: 1-14. DOI:10.1051/kmae/2012018
"dbc_offline"

#' taxaList
#'
#' List of taxa names used in all indices. Gets updated user-end if a new DBC is found
#'
#' @format A data frame with names of 9806 taxa
#' @docType data
#' @usage data(taxaList)
#' @encoding UTF-8
"taxaList"

#' DES
#'
#' Index values for diatom species included in the DES index
#'
#' @format A data frame with the ecological values for 622 species
#' @docType data
#' @usage data(des)
#' @encoding UTF-8
#' @source \url{https://pascal-francis.inist.fr/vibad/index.php?action=getRecordDetail&idt=PASCAL8060205402}
#' @references Descy, J. P. 1979. A new approach to water qualityestimation  using  diatom.  Beih.  Nov  Hedw. 64:305-323
"des"

#' EPID
#'
#' Index values for diatom species included in the EPID index
#'
#' @format A data frame with the ecological values for 1038 species
#' @docType data
#' @usage data(epid)
#' @encoding UTF-8
#' @source \url{https://www.tib.eu/en/search/id/BLCP:CN034949165/Use-of-algae-for-monitoring-rivers-in-the-Czech?cHash=fdd9e0b1bf812a31ec0f692a273cab04}
#' @references Dell'Uomo, A. (1996). Assessment of water quality of an Apennine river as a pilot study for diatom-based monitoring of Italian watercourses. Use of algae for monitoring rivers, 65-72.
"epid"

#' IDAP
#'
#' Index values for diatom species included in the IDAP index
#'
#' @format A data frame with the ecological values for 194 species
#' @docType data
#' @usage data(idap)
#' @encoding UTF-8
#' @source \url{https://link.springer.com/article/10.1007/BF00028033}
#' @references Prygiel, J., & Coste, M. (1993). The assessment of water quality in the Artois-Picardie water basin (France) by the use of diatom indices. Hydrobiologia, 269(1), 343-349.
"idap"

#' ID-CH
#'
#' Index values for diatom species included in the IC-CH index
#'
#' @format A data frame with the ecological values for 550 species
#' @docType data
#' @usage data(idch)
#' @encoding UTF-8
#' @source \url{https://www.bafu.admin.ch/bafu/fr/home/themes/eaux/publications/publications-eaux/methodes-analyse-appreciation-cours-eau-diatomees.html}
#' @references Hürlimann J., Niederhauser P. (2007). Méthodes d’analyse et d’appréciation des cours d’eau. Diatomées Niveau R (région). État de l’environnement n° 0740. Office fédéral de l’environnement, Berne. 132 p
"idch"

#' IDP
#'
#' Index values for diatom species included in the IDP index
#'
#' @format A data frame with the ecological values for 475 species
#' @docType data
#' @usage data(idp)
#' @encoding UTF-8
#' @source \url{https://link.springer.com/article/10.1023/A:1011415209445}
#' @references Gómez, N., & Licursi, M. (2001). The Pampean Diatom Index (IDP) for assessment of rivers and streams in Argentina. Aquatic Ecology, 35(2), 173-181.
"idp"

#' ILM
#'
#' Index values for diatom species included in the ILM index
#'
#' @format A data frame with the ecological values for 667 species
#' @docType data
#' @usage data(ilm)
#' @encoding UTF-8
#' @source \url{https://www.vliz.be/imisdocs/publications/286641.pdf}
#' @references Leclercq, L., & Maquet, B. (1987). Deux nouveaux indices diatomique et de qualité chimique des eaux courantes. Comparaison avec différents indices existants. Cahier de Biology Marine, 28, 303-310
"ilm"

#' IPS
#'
#' Index values for diatom species included in the IPS index
#'
#' @format A data frame with the ecological values for 6881 species
#' @docType data
#' @usage data(ips)
#' @encoding UTF-8
#' @source \url{https://www.documentation.eauetbiodiversite.fr/notice/etude-des-methodes-biologiques-d-appreciation-quantitative-de-la-qualite-des-eaux0}
#' @references Coste, M. (1982). Étude des méthodes biologiques d’appréciation quantitative de la qualité des eaux. Rapport Cemagref QE Lyon-AF Bassin Rhône Méditerranée Corse.
"ips"

#' LOBO
#'
#' Index values for diatom species included in the LOBO index
#'
#' @format A data frame with the ecological values for 297 species
#' @docType data
#' @usage data(lobo)
#' @encoding UTF-8
#' @references Lobo, E. A., Callegaro, V. L. M., & Bender, E. P. (2002). Utilização de algas diatomáceas epilíticas como indicadoras da qualidade da água em rios e arroios da Região Hidrográfica do Guaíba, RS, Brasil. Edunisc.
"lobo"

#' SLA
#'
#' Index values for diatom species included in the SLA index
#'
#' @format A data frame with the ecological values for 976 species
#' @docType data
#' @usage data(sla)
#' @encoding UTF-8
#' @source \url{https://onlinelibrary.wiley.com/doi/abs/10.1002/aheh.19860140519}
#' @references Sládeček, V. (1986). Diatoms as indicators of organic pollution. Acta hydrochimica et hydrobiologica, 14(5), 555-566.
"sla"

#' SPEAR(h)
#'
#' Index values for diatom species included in the SPEAR(h) index
#'
#' @format A data frame with the ecological values for 285 species
#' @docType data
#' @usage data(spear)
#' @encoding UTF-8
#' @source \doi{10.1016/j.ecolind.2018.12.035}
#' @references Wood, R. J., Mitrovic, S. M., Lim, R. P., Warne, M. S. J., Dunlop, J., & Kefford, B. J. (2019). Benthic diatoms as indicators of herbicide toxicity in rivers–A new SPEcies At Risk (SPEARherbicides) index. Ecological Indicators, 99, 203-213.
"spear"

#' TDI
#'
#' Index values for diatom species included in the TDI index
#'
#' @format A data frame with the ecological values for 3445 species
#' @docType data
#' @usage data(tdi)
#' @encoding UTF-8
#' @source \url{https://link.springer.com/article/10.1007/BF00003802}
#' @references Kelly, M. G., & Whitton, B. A. (1995). The trophic diatom index: a new index for monitoring eutrophication in rivers. Journal of Applied Phycology, 7(4), 433-444.
"tdi"

#' PBIDW
#'
#' Index values for diatom species included in the PBIDW index
#'
#' @format A data frame with the ecological values for 79 species
#' @docType data
#' @usage data(pbidw)
#' @encoding UTF-8
#' @source \url{https://www.researchgate.net/publication/270591536_Periphytic_diatom_index_for_assessing_the_ecological_quality_of_the_Colombian_Andean_urban_wetlands_of_Bogota}
#' @references Castro-Roa, D., & Pinilla-Agudelo, G. (2014). Periphytic diatom index for assessing the ecological quality of the Colombian Andean urban wetlands of Bogotá. Limnetica, 33(2), 297-312.
"pbidw"

#' DISP
#'
#' Index values for diatom species included in the DISP index
#'
#' @format A data frame with the ecological values for 143 species
#' @docType data
#' @usage data(disp)
#' @encoding UTF-8
#' @source \doi{10.1016/j.ecolind.2018.07.026}
#' @references Stenger-Kovács, C., Körmendi, K., Lengyel, E., Abonyi, A., Hajnal, É., Szabó, B., Buczkó, K. & Padisák, J. (2018). Expanding the trait-based concept of benthic diatoms: Development of trait-and species-based indices for conductivity as the master variable of ecological status in continental saline lakes. Ecological Indicators, 95, 63-74.
"disp"

#' CEMFGS_RB
#'
#' Index values for diatom species combining their ecological guilds with their size classes
#'
#' @format A data frame with the ecological values for 495 species
#' @docType data
#' @usage data(cemfgs_rb)
#' @encoding UTF-8
#' @source \doi{10.1016/j.ecolind.2017.07.007}
#' @references B-Béres, V., Török, P., Kókai, Z., Lukács, Á., Enikő, T., Tóthmérész, B., & Bácsi, I. (2017). Ecological background of diatom functional groups: Comparability of classification systems. Ecological Indicators, 82, 183-188.
"cemfgs_rb"

#' EDI
#'
#' Index values for diatom species included in the EDI index
#'
#' @format A data frame with the ecological values for 147 species
#' @docType data
#' @usage data(edi)
#' @encoding UTF-8
#' @source \url{https://pubs.acs.org/doi/abs/10.1021/acsestwater.4c00126}
#' @references Chamorro, S., Moyón, J., Salazar, J., Chamorro, K., Vicuña, Z., Cordero, P., Bécares, E. & Blanco, S. (2024). Water Quality Monitoring in Ecuadorian Streams Using a New Diatom-Based Index. ACS ES&T Water, 4(9), 3816-3823.
"edi"

#' DDI
#'
#' Index values for diatom species included in the DDI index
#'
#' @format A data frame with the ecological values for 137 species
#' @docType data
#' @usage data(ddi)
#' @encoding UTF-8
#' @source \url{https://link.springer.com/article/10.1007/s10661-012-2607-z}
#' @references Álvarez-Blanco, I., Blanco, S., Cejudo-Figueiras, C., & Bécares, E. (2013). The Duero Diatom Index (DDI) for river water quality assessment in NW Spain: design and validation. Environmental monitoring and assessment, 185, 969-981.
"ddi"

#' PDISE
#'
#' Index values for diatom species included in the PDIse index
#'
#' @format A data frame with the ecological values for 455 species
#' @docType data
#' @usage data(pdise)
#' @encoding UTF-8
#' @source \url{https://link.springer.com/article/10.1007/s10661-023-11378-4}
#' @references Kahlert, M., Fölster, J., & Tapolczai, K. (2023). No lukewarm diatom communities—the response of freshwater benthic diatoms to phosphorus in streams as basis for a new phosphorus diatom index (PDISE). Environmental Monitoring and Assessment, 195(7), 807
"pdise"
